@@ -179,7 +179,7 @@ funcunit(struct unittype *theunit, struct function const *fun)
     err=unit2num(theunit);
     if (err==E_NOTANUMBER){
       initializeunit(&angleunit);
-      angleunit.denominator[0] = dupstr("radian");
+      angleunit.denominator[0] = dupstr("radian","(funcunit)");
       angleunit.denominator[1] = 0;
       err = multunit(theunit, &angleunit);
       freeunit(&angleunit);
@@ -200,7 +200,7 @@ funcunit(struct unittype *theunit, struct function const *fun)
   if (errno)
     return E_FUNC;
   if (fun->type==ANGLEOUT) {
-    theunit->numerator[0] = dupstr("radian");
+    theunit->numerator[0] = dupstr("radian","(funcunit)");
     theunit->numerator[1] = 0;
   }
   return 0;
@@ -1626,43 +1626,43 @@ yyreduce:
 
   case 34: /* list: BADNUMBER  */
 #line 275 "parse.y"
-                                   { err = E_BADNUM;   CHECK(0); }
+                                   { err = E_BADNUM;   CHECK(0); (yyval.unit)=NULL;}
 #line 1631 "parse.tab.c"
     break;
 
   case 35: /* list: NUMOVERFLOW  */
 #line 276 "parse.y"
-                                   { err = E_OVERFLOW; CHECK(0); }
+                                   { err = E_OVERFLOW; CHECK(0); (yyval.unit)=NULL;}
 #line 1637 "parse.tab.c"
     break;
 
   case 36: /* list: NUMUNDERFLOW  */
 #line 277 "parse.y"
-                                   { err = E_UNDERFLOW;CHECK(0); }
+                                   { err = E_UNDERFLOW;CHECK(0); (yyval.unit)=NULL;}
 #line 1643 "parse.tab.c"
     break;
 
   case 37: /* list: MEMERROR  */
 #line 278 "parse.y"
-                                   { err = E_PARSEMEM; CHECK(0); }
+                                   { err = E_PARSEMEM; CHECK(0); (yyval.unit)=NULL;}
 #line 1649 "parse.tab.c"
     break;
 
   case 38: /* list: UNITEND  */
 #line 279 "parse.y"
-                                   { err = E_UNITEND;  CHECK(0); }
+                                   { err = E_UNITEND;  CHECK(0); (yyval.unit)=NULL;}
 #line 1655 "parse.tab.c"
     break;
 
   case 39: /* list: LASTUNSET  */
 #line 280 "parse.y"
-                                   { err = E_LASTUNSET;CHECK(0); }
+                                   { err = E_LASTUNSET;CHECK(0); (yyval.unit)=NULL;}
 #line 1661 "parse.tab.c"
     break;
 
   case 40: /* list: FUNCINV UNIT  */
 #line 281 "parse.y"
-                                   { err = E_NOTAFUNC; CHECK((yyvsp[0].unit));}
+                                   { err = E_NOTAFUNC; CHECK((yyvsp[0].unit));(yyval.unit)=NULL;}
 #line 1667 "parse.tab.c"
     break;
 
@@ -1997,8 +1997,9 @@ int yylex(YYSTYPE *lvalp, struct commtype *comm)
   /* Look for a word (function name or unit name) */
 
   length = strcspn(inptr,nonunitchars);   
-
+  
   if (!length){  /* Next char is not a valid unit char */
+    printf("skipping invalid: '%c'\n",*inptr);
      comm->location++;
      return 0;
   }
@@ -2032,7 +2033,7 @@ int yylex(YYSTYPE *lvalp, struct commtype *comm)
     return 0;
   }
 
-  name = dupnstr(inptr, length);
+  name = dupnstr(inptr, length, "(yylex)");
 
   /* Look for string operators */
 
@@ -2111,7 +2112,7 @@ int yylex(YYSTYPE *lvalp, struct commtype *comm)
     return MEMERROR;
   output->numerator[count--]=0;
   for(;count>=0;count--)
-    output->numerator[count] = dupnstr(inptr, length);
+    output->numerator[count] = dupnstr(inptr, length, "(yylex)");
   lvalp->unit=output;
   return UNIT;
 }
