@@ -62,28 +62,31 @@
 #define E_PARSE 1
 #define E_PRODOVERFLOW 2
 #define E_REDUCE 3
-#define E_BADSUM 4
-#define E_NOTANUMBER 5
-#define E_NOTROOT 6
-#define E_UNKNOWNUNIT 7
-#define E_FUNC 8         /* If errno is set after calling a function */
-#define E_BADFUNCTYPE 9
-#define E_BADFUNCARG 10
-#define E_NOTINDOMAIN 11
-#define E_BADFUNCDIMEN 12
-#define E_NOINVERSE 13
-#define E_PARSEMEM 14
-#define E_FUNARGDEF 15
-#define E_FILE 16
-#define E_BADFILE 17
-#define E_MEMORY 18
-#define E_BADNUM 19
-#define E_UNITEND 20 
-#define E_LASTUNSET 21
-#define E_IRRATIONAL_EXPONENT 22
-#define E_BASE_NOTROOT 23
-#define E_DIMEXPONENT 24
-#define E_NOTAFUNC 25
+#define E_CIRCULARDEF 4
+#define E_BADSUM 5
+#define E_NOTANUMBER 6
+#define E_NOTROOT 7
+#define E_UNKNOWNUNIT 8
+#define E_FUNC 9         /* If errno is set after calling a function */
+#define E_BADFUNCTYPE 10
+#define E_BADFUNCARG 11
+#define E_NOTINDOMAIN 12
+#define E_BADFUNCDIMEN 13
+#define E_NOINVERSE 14
+#define E_PARSEMEM 15
+#define E_FUNARGDEF 16
+#define E_FILE 17
+#define E_BADFILE 18
+#define E_MEMORY 19
+#define E_BADNUM 20
+#define E_UNITEND 21
+#define E_LASTUNSET 22
+#define E_IRRATIONAL_EXPONENT 23
+#define E_BASE_NOTROOT 24
+#define E_DIMEXPONENT 25
+#define E_NOTAFUNC 26
+#define E_OVERFLOW 27
+#define E_UNDERFLOW 28
 
 extern char *errormsg[];
 
@@ -144,7 +147,7 @@ extern char *function_parameter;
 extern int lastunitset;
 extern struct unittype lastunit;
 
-void *mymalloc(int bytes, const char *mesg);
+void *mymalloc(size_t bytes, const char *mesg);
 int hassubscript(const char *str);
 void initializeunit(struct unittype *theunit);
 void freeunit(struct unittype *theunit);
@@ -156,8 +159,8 @@ int expunit(struct unittype *theunit, int  power);
 int addunit(struct unittype *unita, struct unittype *unitb);
 int rootunit(struct unittype *inunit,int n);
 int unitpower(struct unittype *base, struct unittype *exponent);
-char *dupstr(const char *str);
-char *dupnstr(const char *string, int length);
+char *dupstr(const char *str, const char *msg);
+char *dupnstr(const char *string, size_t length, const char *msg);
 int unit2num(struct unittype *input);
 struct func *fnlookup(const char *str);
 int evalfunc(struct unittype *theunit, struct func *infunc, int inverse, 
